@@ -5,7 +5,7 @@ describe 'glance::client' do
   shared_examples 'glance client' do
     it { is_expected.to contain_class('glance::params') }
     it { is_expected.to contain_package('python-glanceclient').with(
-        :name   => 'python-glanceclient',
+        :name   => platform_params[:client_package_name],
         :ensure => 'present',
         :tag    => ['openstack', 'glance-support-package'],
       )
